Package: MCPAN
Type: Package
Title: Multiple Comparisons Using Normal Approximation
Version: 1.1-22
Date: 2026-05-05
Authors@R: c(person("Frank", "Schaarschmidt", role=c("aut","cre"), email="schaarschmidt@biostat.uni-hannover.de"),
 person("Daniel", "Gerhard", role="aut"),
 person("Martin", "Sill", role="aut"))
Author: Frank Schaarschmidt [aut, cre],
  Daniel Gerhard [aut],
  Martin Sill [aut]
Maintainer: Frank Schaarschmidt <schaarschmidt@biostat.uni-hannover.de>
Imports: mvtnorm, multcomp, graphics, stats, magic, MCMCpack, plyr
Description: Multiple contrast tests and simultaneous confidence
 intervals based on normal approximation. With implementations for
 binomial proportions in a 2xk setting (risk difference and odds ratio),
 poly-3-adjusted tumour rates, biodiversity indices (multinomial data) 
 and expected values under lognormal assumption. Approximative power 
 calculation for multiple contrast tests of binomial and Gaussian data.
License: GPL-2
NeedsCompilation: no
Packaged: 2026-05-07 07:28:44 UTC; root
Repository: CRAN
Date/Publication: 2026-05-08 05:20:35 UTC
Built: R 4.5.2; ; 2026-05-08 06:48:50 UTC; unix
