\name{Simpson}
\alias{Simpson}

\title{ Calculate the Simpson index }
\description{
 Calculate the Simpson index from a vector of proportions.
}
\usage{
Simpson(p)
}
\arguments{
  \item{p}{ a numeric vector of proportions }
}

\keyword{ internal }

