\name{Shannon}
\alias{Shannon}

\title{ Shannon index }
\description{
 Calculates the Shannon-Wiener index.
}
\usage{
Shannon(p)
}

\arguments{
  \item{p}{A numeric vector of proportions. }
}



\keyword{ internal }

